package com.mcwl.web.controller.communityCenter;

import com.mcwl.common.core.domain.R;
import com.mcwl.common.core.page.PageDomain;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.communityCenter.domain.dto.EditPublishReportStatusRes;
import com.mcwl.communityCenter.domain.dto.PublishReportRes;
import com.mcwl.communityCenter.service.PublishReportService;
import com.mcwl.communityCenter.service.PublishService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

/**
 * 发布举报
 */
@Api(tags = "发布举报")
@RestController
@RequestMapping("publishReport")
@RequiredArgsConstructor
public class PublishReportController {

    private final PublishReportService publishReportService;

    /**
     * 获取举报列表
     */
    @ApiOperation(value = "获取举报列表")
    @PostMapping("list")
    public TableDataInfo getReportList(@RequestBody @Valid PageDomain pageDomain) {
        return publishReportService.getReportList(pageDomain);
    }

    /**
     * 修改状态
     */
    @ApiOperation(value = "修改状态")
    @PostMapping("updateStatus")
    public R<Object> updateStatus(@RequestBody @Valid EditPublishReportStatusRes editPublishReportStatusRes) {
        publishReportService.updateStatus(editPublishReportStatusRes);
        return R.ok();
    }

    /**
     * 删除举报
     */
    @ApiOperation(value = "删除举报")
    @GetMapping("delete")
    public R<Object> delete(@Valid @NotNull(message = "举报id不能为空") Long id) {
        publishReportService.removeReportById(id);
        return R.ok();
    }



}
