package com.mcwl.web.controller.resource;

import com.mcwl.common.constant.HttpStatus;
import com.mcwl.common.core.domain.R;
import com.mcwl.resource.domain.PcVersion;
import com.mcwl.resource.service.impl.PcVersionServiceImpl;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * pc端版本
 *
 * @author DaiZibo
 * @date 2025/5/9
 * @apiNote
 */

@Api(tags = "pc端版本")
@RequestMapping("/version")
@RestController
public class PcVersionController {

    @Autowired
    private PcVersionServiceImpl pcVersionService;

    @ApiOperation(value = "查看pc版本列表")
    @PostMapping("/list")
    public R<List<PcVersion>> selectList(){

        List<PcVersion> pcVersionList = pcVersionService.selectList();
        return R.ok(pcVersionList);
    }

    @ApiOperation(value = "修改版本")
    @PostMapping("/update")
    public R update(@RequestBody PcVersion pcVersion){

        pcVersionService.update(pcVersion);
        return R.ok();
    }


    @ApiOperation(value = "根据版本号查询版本")
    @PostMapping("/selectVersion")
    public R selectVersion(@RequestParam String versionNumber){

        PcVersion pcVersion = pcVersionService.selectVersion(versionNumber);

        return  R.ok(pcVersion);
    }

    @ApiOperation(value = "新增版本")
    @PostMapping("/addVersion")
    public R addVersion(@RequestBody PcVersion pcVersion){

        //校验版本号
        PcVersion pcVersion1 = pcVersionService.selectVersion(pcVersion.getVersionNumber());
        if (pcVersion1 != null){

            return R.fail(HttpStatus.SHOW_ERROR_MSG,"版本号重复");
        }
        pcVersionService.addVersion(pcVersion);

        return  R.ok();
    }



}
