package com.mcwl.web.controller.system;


import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.mcwl.common.constant.HttpStatus;
import com.mcwl.common.core.domain.R;
import com.mcwl.system.domain.SysEmail;
import com.mcwl.system.domain.SysTool;
import com.mcwl.system.domain.dto.AddEmailRes;
import com.mcwl.system.domain.dto.AddToolRes;
import com.mcwl.system.domain.dto.EditEmailRes;
import com.mcwl.system.domain.dto.EditToolRes;
import com.mcwl.system.domain.vo.EmailVo;
import com.mcwl.system.domain.vo.ToolVo;
import com.mcwl.system.service.ISysEmailService;
import com.mcwl.system.service.ISysToolService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/***
 * 工具
 */
@RestController
@RequestMapping("sys/tool")
@RequiredArgsConstructor
@Api(tags = "工具")
public class SysToolController {

    private final ISysToolService sysToolService;


    /**
     * 查询工具列表
     */
    @GetMapping("listTool")
    @ApiOperation(value = "查询工具列表")
    public R<List<ToolVo>> listTool(@ApiParam(value = "工具类型") @RequestParam(required = false) Integer type) {
        List<SysTool> sysToolList = sysToolService.list(new LambdaQueryWrapper<SysTool>()
                .eq(type != null, SysTool::getType, type)
                .orderByDesc(SysTool::getStatus)
                .orderByDesc(SysTool::getCreateTime));
        List<ToolVo> toolVoList = new ArrayList<>();
        for (SysTool sysTool : sysToolList) {
            ToolVo toolVo = BeanUtil.toBean(sysTool, ToolVo.class);
            if (sysTool.getType() == 0) {
                toolVo.setTypeName("文本");
            } else if (sysTool.getType() == 1) {
                toolVo.setTypeName("图片");
            } else if (sysTool.getType() == 2) {
                toolVo.setTypeName("视频");
            }
            toolVoList.add(toolVo);
        }

        return R.ok(toolVoList);
    }

    /**
     * 按id查询工具
     */
    @GetMapping("getTool")
    @ApiOperation(value = "按id查询工具")
    public R<ToolVo> getTool(@Valid @NotNull(message = "工具id不能为空") Long toolId) {
        SysTool sysTool = sysToolService.getById(toolId);
        ToolVo toolVo = BeanUtil.toBean(sysTool, ToolVo.class);
        if (sysTool.getType() == 0) {
            toolVo.setTypeName("文本");
        } else if (sysTool.getType() == 1) {
            toolVo.setTypeName("图片");
        } else if (sysTool.getType() == 2) {
            toolVo.setTypeName("视频");
        }
        return R.ok(toolVo);
    }

    @PostMapping("addTool")
    @ApiOperation(value = "添加工具")
    public R<String> addTool(@Valid @RequestBody AddToolRes addToolRes) {

        SysTool sysTool = BeanUtil.toBean(addToolRes, SysTool.class);
        return sysToolService.save(sysTool) ? R.ok(null, "添加成功") : R.fail(null, "添加失败");
    }

    /**
     * 编辑工具
     */
    @PostMapping("editTool")
    @ApiOperation(value = "编辑工具")
    public R<String> editTool(@Valid @RequestBody EditToolRes editToolRes) {
        SysTool sysTool = BeanUtil.toBean(editToolRes, SysTool.class);
        return sysToolService.updateById(sysTool) ? R.ok(null, "编辑成功") : R.fail(null, "编辑失败");
    }

    /**
     * 删除工具
     */
    @GetMapping("delTool")
    @ApiOperation(value = "删除工具")
    public R<String> delTool(@Valid @NotNull(message = "工具id不能为空") Long toolId) {
        return sysToolService.removeById(toolId) ? R.ok(null, "删除成功") : R.fail(null, "删除失败");
    }


}
